==> org.eclipse.launchbar.ui.source_2.2.0.201711162100.jar: org/eclipse/launchbar/ui/internal/Messages.java <==
/*******************************************************************************
 * Copyright (c) 2014, 2016 QNX Software Systems and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package org.eclipse.launchbar.ui.internal;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.launchbar.ui.internal.messages"; //$NON-NLS-1$

	public static String BuildActiveCommandHandler_0;
	public static String BuildActiveCommandHandler_1;
	public static String StopActiveCommandHandler_0;
	public static String StopActiveCommandHandler_1;

	public static String NewLaunchConfigEditPage_0;
	public static String NewLaunchConfigEditPage_1;
	public static String NewLaunchConfigEditPage_2;
	public static String NewLaunchConfigEditPage_3;
	public static String NewLaunchConfigEditPage_4;
	public static String NewLaunchConfigEditPage_5;
	public static String NewLaunchConfigEditPage_6;
	public static String NewLaunchConfigEditPage_7;
	public static String NewLaunchConfigModePage_0;
	public static String NewLaunchConfigModePage_1;
	public static String NewLaunchConfigModePage_2;
	public static String NewLaunchConfigTypePage_0;
	public static String NewLaunchConfigTypePage_1;
	public static String NewLaunchConfigTypePage_2;

	public static String NewLaunchConfigTypePage2_Mode;

	public static String NewLaunchConfigTypePage2_Type;
	public static String NewLaunchConfigWizard_0;

	public static String NewLaunchTargetWizard_Title;

	public static String NewLaunchTargetWizardSelectionPage_Description;

	public static String NewLaunchTargetWizardSelectionPage_Title;

	public static String DescriptorMustNotBeNull;
	public static String DescriptorMustNotBeNullDesc;
	public static String NoActiveTarget;
	public static String NoActiveTargetDesc;
	public static String NoLaunchConfigType;
	public static String CannotEditLaunchConfiguration;
	public static String NoLaunchModeSelected;
	public static String NoLaunchGroupSelected;
	public static String LaunchBarLaunchConfigDialog_Edit1;

	public static String LaunchBarLaunchConfigDialog_Edit2;

	public static String LaunchBarLaunchConfigDialog_EditConfiguration;

	public static String LaunchBarLaunchConfigDialog_LaunchConfigName;

	public static String LaunchBarLaunchConfigDialog_LCMustHaveName;

	public static String LaunchBarLaunchConfigDialog_LCNameExists;

	public static String LaunchBarLaunchConfigDialog_LCNameNotValid;

	public static String LaunchBarLaunchConfigDialog_SetParameters;

	public static String LaunchConfigurationNotFound;
	public static String LaunchConfigurationNotFoundDesc;

	public static String LaunchTargetWizardDialog_Delete;
	public static String NoLaunchTabsDefined;
	public static String NoLaunchTabsDefinedDesc;

	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}

==> org.eclipse.launchbar.ui.source_2.5.400.202403071917.jar: org/eclipse/launchbar/ui/internal/Messages.java <==
/*******************************************************************************
 * Copyright (c) 2014, 2016 QNX Software Systems and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *******************************************************************************/
package org.eclipse.launchbar.ui.internal;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.launchbar.ui.internal.messages"; //$NON-NLS-1$

	public static String BuildActiveCommandHandler_0;
	public static String BuildActiveCommandHandler_1;
	public static String StopActiveCommandHandler_0;
	public static String StopActiveCommandHandler_1;

	public static String NewLaunchConfigEditPage_0;
	public static String NewLaunchConfigEditPage_1;
	public static String NewLaunchConfigEditPage_2;
	public static String NewLaunchConfigEditPage_3;
	public static String NewLaunchConfigEditPage_4;
	public static String NewLaunchConfigEditPage_5;
	public static String NewLaunchConfigEditPage_6;
	public static String NewLaunchConfigEditPage_7;
	public static String NewLaunchConfigModePage_0;
	public static String NewLaunchConfigModePage_1;
	public static String NewLaunchConfigModePage_2;
	public static String NewLaunchConfigTypePage_0;
	public static String NewLaunchConfigTypePage_1;
	public static String NewLaunchConfigTypePage_2;

	public static String NewLaunchConfigTypePage2_Mode;

	public static String NewLaunchConfigTypePage2_Type;
	public static String NewLaunchConfigWizard_0;

	public static String NewLaunchTargetWizard_Title;

	public static String NewLaunchTargetWizardSelectionPage_Description;

	public static String NewLaunchTargetWizardSelectionPage_Title;

	public static String DescriptorMustNotBeNull;
	public static String DescriptorMustNotBeNullDesc;
	public static String NoActiveTarget;
	public static String NoActiveTargetDesc;
	public static String NoLaunchConfigType;
	public static String CannotEditLaunchConfiguration;
	public static String NoLaunchModeSelected;
	public static String NoLaunchGroupSelected;
	public static String LaunchBarLaunchConfigDialog_Edit1;
	public static String LaunchBarLaunchConfigDialog_Edit2;
	public static String LaunchBarLaunchConfigDialog_EditConfiguration;
	public static String LaunchBarLaunchConfigDialog_LaunchConfigName;
	public static String LaunchBarLaunchConfigDialog_LCMustHaveName;
	public static String LaunchBarLaunchConfigDialog_LCNameExists;
	public static String LaunchBarLaunchConfigDialog_LCNameNotValid;
	public static String LaunchBarLaunchConfigDialog_SetParameters;
	public static String LaunchBarLaunchConfigDialog_Duplicate;
	public static String LaunchBarLaunchConfigDialog_Delete;
	public static String LaunchBarLaunchConfigDialog_Reset;
	public static String LaunchBarLaunchConfigDialog_DeleteTitle;
	public static String LaunchBarLaunchConfigDialog_ResetTitle;
	public static String LaunchBarLaunchConfigDialog_DeleteConfirm;
	public static String LaunchBarLaunchConfigDialog_ResetConfirm;

	public static String LaunchConfigurationNotFound;
	public static String LaunchConfigurationNotFoundDesc;

	public static String LaunchTargetWizardDialog_Delete;
	public static String NoLaunchTabsDefined;
	public static String NoLaunchTabsDefinedDesc;

	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}
